# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

caMaterial: Optional[str]
"""
PEM-encoded content of Docker host CA certificate
"""

certMaterial: Optional[str]
"""
PEM-encoded content of Docker client certificate
"""

certPath: Optional[str]
"""
Path to directory with Docker TLS config
"""

context: Optional[str]
"""
The name of the Docker context to use. Can also be set via `DOCKER_CONTEXT` environment variable. Overrides the `host` if set.
"""

disableDockerDaemonCheck: Optional[bool]
"""
If set to `true`, the provider will not check if the Docker daemon is running. This is useful for resources/data_sourcess that do not require a running Docker daemon, such as the data source `RegistryImage`.
"""

host: Optional[str]
"""
The Docker daemon address
"""

keyMaterial: Optional[str]
"""
PEM-encoded content of Docker client private key
"""

registryAuth: Optional[str]

sshOpts: Optional[str]
"""
Additional SSH option flags to be appended when using `ssh://` protocol
"""

